@@ -2,14 +2,12 @@ package Gscan2pdf::Dialog::Scan::Image_Sane;
 
 use warnings;
 use strict;
-no if $] >= 5.018, warnings => 'experimental::smartmatch';
 use Glib qw(TRUE FALSE);   # To get TRUE and FALSE
 use Image::Sane ':all';    # To get SANE_NAME_PAGE_WIDTH & SANE_NAME_PAGE_HEIGHT
 use Gscan2pdf::Dialog::Scan;
 use Gscan2pdf::Frontend::Image_Sane;
 use Gscan2pdf::Translation '__';    # easier to extract strings with xgettext
 use Locale::gettext 1.05;           # For translations
-use feature 'switch';
 use Data::Dumper;
 $Data::Dumper::Sortkeys = 1;
 use Readonly;
@@ -41,7 +39,7 @@ use Glib::Object::Subclass Gscan2pdf::Dialog::Scan::, properties => [
     ),
 ];
 
-our $VERSION = '2.13.2';
+our $VERSION = '2.13.3';
 
 my $SANE_NAME_SCAN_TL_X   = SANE_NAME_SCAN_TL_X;
 my $SANE_NAME_SCAN_TL_Y   = SANE_NAME_SCAN_TL_Y;
@@ -295,6 +293,17 @@ sub _initialise_options {    ## no critic (ProhibitExcessComplexity)
                 if ( $opt->{constraint}{quant} ) {
                     $step = $opt->{constraint}{quant};
                 }
+                if ( $opt->{constraint}{min} > $opt->{constraint}{max} ) {
+                    $logger->error(
+                        sprintf __(
+"Ignoring scan option '%s', minimum range (%s) > maximum (%s)"
+                        ),
+                        $opt->{name},
+                        $opt->{constraint}{min},
+                        $opt->{constraint}{max}
+                    );
+                    next;
+                }
                 $widget =
                   Gtk3::SpinButton->new_with_range( $opt->{constraint}{min},
                     $opt->{constraint}{max}, $step );
@@ -359,7 +368,7 @@ sub _initialise_options {    ## no critic (ProhibitExcessComplexity)
                 );
             }
         }
-        else {    # $opt->{max_values} > 1
+        else {                                       # $opt->{max_values} > 1
             $widget = Gtk3::Button->new( $d_sane->get( $opt->{title} ) );
             $widget->{signal} = $widget->signal_connect(
                 clicked =>
