@@ -3,10 +3,8 @@ package Gscan2pdf::Page;
 use 5.008005;
 use strict;
 use warnings;
-use feature 'switch';
-no if $] >= 5.018, warnings => 'experimental::smartmatch';
 use Carp;
-use Glib qw(TRUE FALSE);    # To get TRUE and FALSE
+use Glib qw(TRUE FALSE);             # To get TRUE and FALSE
 use File::Copy;
 use File::Temp;                      # To create temporary files
 use Image::Magick;
@@ -31,7 +29,7 @@ BEGIN {
     use Exporter ();
     our ( $VERSION, @EXPORT_OK, %EXPORT_TAGS );
 
-    $VERSION = '2.13.2';
+    $VERSION = '2.13.3';
 
     use base qw(Exporter);
     %EXPORT_TAGS = ();    # eg: TAG => [ qw!name1 name2! ],
